;========================================================================================================
; Vertical Nanowire Gate All Around P-type Junctionless Nanotransistor
; SDE command file: pmos_inverter
;========================================================================================================
;
;========================================================================================================
; Geometry, doping and mesh refinement parameters
;========================================================================================================
; dimensions along x (horizontal, channel direction) are indicated as "lengths"
; dimensions along y (vertical direction) are indicated as "thicknesses"
; increasing y values are plotted from top to bottom (!!)
;
; Nanowire DIAMETER = 20 nm
; Nanowire LENGTH = 78 nm
; Oxide THICKNESS = 5 nm
; Gate LENGTH = 18 nm
; Top spacer LENGTH = 30 nm
; Bottom spacer LENGTH = 30 nm

(define nw_radius 100e-4)
(define ox_radius 150e-4)
(define bot_spacer 70e-3)
(define gat_spacer 88e-3)
(define top_spacer 133e-3)
(define gate_contact 79e-3)

;========================================================================================================
; Definition of the geometry
;========================================================================================================
; Porzione inferiore nanowire
(define A (sdegeo:create-cylinder (position 0 0 0) (position bot_spacer 0 0)  			nw_radius "Silicon" "core"))

; Porzione sotto gate nanowire
(define B (sdegeo:create-cylinder (position bot_spacer 0 0) (position gat_spacer 0 0)  	nw_radius "Silicon" "core"))

; Porzione superiore nanowire
(define C (sdegeo:create-cylinder (position gat_spacer 0 0) (position top_spacer 0 0)  	nw_radius "Silicon" "core"))

(sdegeo:bool-unite (list A B C))

; Creazione dell'ossido
(sdegeo:set-default-boolean "XX")
(define A (sdegeo:create-cylinder (position 0 0 0) (position top_spacer 0 0)  ox_radius "SiO2" "oxide"))
(define B (sdegeo:create-cylinder (position 0 0 0) (position top_spacer 0 0)  nw_radius "SiO2" "oxide"))
(sdegeo:bool-subtract (list A B))

; Creazione del gate (gate length = 18.0 nm)
(define A (sdegeo:create-cuboid (position bot_spacer -60e-3 -60e-3) (position gat_spacer 60e-3 250e-3) "Metal" "gate"))
(define B (sdegeo:create-cylinder (position 0 0 0) (position top_spacer 0 0)  ox_radius "SiO2" "gate"))
(sdegeo:bool-subtract (list A B))

;========================================================================================================
; Definition of the contacts
;========================================================================================================
; Gate contact
(sdegeo:define-contact-set "Gate" 4 (color:rgb 0 0 1) "##")
(sdegeo:set-current-contact-set "Gate")
(sdegeo:define-3d-contact (list (car (find-face-id (position gate_contact 0 0.25)))) "Gate")

; Source contact
(sdegeo:define-contact-set      "Source"    4 (color:rgb  1 0 0) "##")
(sdegeo:set-current-contact-set "Source")
(sdegeo:define-3d-contact (list (car (find-face-id (position 0 0.0 0.0)))) "Source")

; Drain contact
(sdegeo:define-contact-set      "Drain"     4 (color:rgb 0 1 0) "##")
(sdegeo:set-current-contact-set "Drain")
(sdegeo:define-3d-contact (list (car (find-face-id (position top_spacer 0.0 0.0)))) "Drain")

;========================================================================================================
; Defining doping profiles
;========================================================================================================
; Nanowire doping
(sdedr:define-constant-profile "ConstantProfileDefinition_1" "BoronActiveConcentration" 1.2e18)
(sdedr:define-constant-profile-region "Doping_p_type" "ConstantProfileDefinition_1" "core" 0 "Replace")

;========================================================================================================
; Defining mesh parameters
;========================================================================================================
(sdedr:define-refinement-size "RefinementDefinition_1" 1e-2 1e-2 1e-2 1e-3 1e-3 1e-3 )
(sdedr:define-refinement-placement "RefinementPlacement_silicide" "RefinementDefinition_1" (list "material" "Metal" ) )
(sdedr:define-refinement-size "RefinementDefinition_1" 1e-2 1e-2 1e-2 1e-3 1e-3 1e-3 )
(sdedr:define-refinement-placement "RefinementPlacement_silicide" "RefinementDefinition_1" (list "material" "SiO2" ) )
(sdedr:define-refinement-size "RefinementDefinition_2" 1e-2 1e-2 1e-2 1e-3 1e-3 1e-3 )
(sdedr:define-refinement-placement "RefinementPlacement_nanowire" "RefinementDefinition_2" (list "material" "Silicon" ) )
(sde:enable-facet-options-usage)
(sde:modify-facet-options sde-facet-opts "surface_tol" -10 "normal_tol" 25 "aspect_ratio" 0 "max_edge_length" 0.004)

;========================================================================================================
; Generate mesh
;========================================================================================================
(sde:set-meshing-command "snmesh")
(sde:build-mesh "-AI" "pmos_inverter")	

